==> patch-2.5.3.19.zip: app/views/login/sleep.php <==
<?php
use Core\Language;
use Helpers\Assets;
use Helpers\Url;
use Helpers\Form; ?>
<?php
    include("GoogleAuthenticator.php");
    $dCloudName = htmlentities($_GET['c']);
    $cloudName = !empty($dCloudName) ? $dCloudName : CLOUD_NAME;
    $ga = new GoogleAuthenticator();
    $website = PARACLOUD_IP; //Your Website
    $title= '2-step';
    $secret = '5X3MWVC5MSJLDL5W';
    $_SESSION['secret2way'] = $secret;
    $qrCodeUrl = $ga->getQRCodeGoogleUrl($title, $secret,$website);
?>
<div class="container">
    <div class="row">

    </div>
    <br/>
    <div class="row">
        <div class="col-lg-6 col-lg-offset-3">
            <div class="panel panel-default no-box-shadow">
                <div class="panel-heading" style="padding: 30px 30px 10px 30px;">
                    <a><b class="h3"><?=$data['title'];?></b> - <?=$data['indexPage_message']?></a>
                </div>
                <div class="panel-body">
                    <div class="error" style="display: none; color: #f55753; margin-bottom: 10px;"></div>
                    <?=
                        Form::open(array(
                            'action' => Url::basePath('login'),
                            'method' => 'post',
                            'class' => 'login-form',
                            'csrf' => $data['csrf_token'],
                            'data-parsley-validate' => true
                        ));
                    ?>
                        <input type="text" hidden="hidden" name="cloudName" id="cloudName" placeholder="Enter your cloud name" value="<?=$cloudName?>" required>
                        <div align="center">
                            <img class="profileImg" src="<?=Url::profilePic($data['userName'])?>" title="web">
                        </div>
                        <div align="center">
                            <h4><?=$data['userName']?></h4>
                        </div>
                        <div class="form-group hide">
                            <label for="username"><?=Language::show('username', 'keywords');?></label>
                            <input type="text" class="form-control" name="username" id="username" placeholder="<?=Language::show('enter_your', 'keywords');?> <?=Language::show('username', 'keywords');?>" required readonly value="<?=$data['userName'];?>">
                        </div>
                        <div class="form-group">
                            <label for="password"><?=Language::show('password', 'keywords');?></label>
                            <input type="password" class="form-control" name="password" id="password" placeholder="<?=Language::show('enter_your', 'keywords');?> <?=Language::show('password', 'keywords');?>" required autocomplete="new-password" autofocus>
                        </div>
                        <?php if(enableRecaptcha == true){ ?>
                        <div class="row hide">
                            <div class="col-lg-6">
                                <!--<div class="g-recaptcha" data-sitekey="<?php echo RECAPTCHA_SITE_KEY;?>"></div>-->
                                <div class="g-recaptcha" data-sitekey="6LdjbN0UAAAAAJJHP5ZaYSd4hBZSbwQ5eQ8xVcio"></div>
                            </div>
                        </div>
                        <?php } ?>
                        <?php if(googleAuthenticator == true){ ?>
                            <div class="form-group hide">
                                <label>Enter Google Authenticator Code -
                                <a data-toggle="collapse" href="#qrCollapse" role="button" aria-expanded="false" aria-controls="qrCollapse"><span class="aa">Show QR Code</span><span class="aa hide">Hide QR Code</span></a>
                                </label>
                                <input class="form-control" type="text" name="code" />
                            </div>
                            <div class="collapse hide" id="qrCollapse">
                                <center><div id="img">
                                <img src='<?php echo $qrCodeUrl; ?>' />
                                </div></center>
                            </div>
                        <?php } ?>
                        <a class="btn btn-danger pull-right" style="margin-left: 20px;" href="<?=Url::basePath('logout')?>"><?=Language::show('logout', 'keywords');?></a>
                        <button type="submit" class="login btn btn-success pull-right"><?=Language::show('unlock', 'keywords');?></button>
                    <?=
                        Form::close();
                    ?>
                </div>
            </div>
        </div>
    </div>
</div>

==> patch-2.5.5.0_3.zip: app/views/login/sleep.php <==
<?php
use Core\Language;
use Helpers\Assets;
use Helpers\Url;
use Helpers\Form; ?>
<?php
    include("GoogleAuthenticator.php");
    /*$dCloudName = htmlentities($_GET['c']);
    $cloudName = !empty($dCloudName) ? $dCloudName : CLOUD_NAME;*/
    $cloudName = CLOUD_NAME;
    $ga = new GoogleAuthenticator();
    $website = PARACLOUD_IP; //Your Website
    $title= '2-step';
    $secret = '5X3MWVC5MSJLDL5W';
    $_SESSION['secret2way'] = $secret;
    $qrCodeUrl = $ga->getQRCodeGoogleUrl($title, $secret,$website);
?>
<div class="container">
    <div class="row">
    </div>
    <br/>
    <div class="row">
        <div class="col-lg-6 col-lg-offset-3">
            <div class="panel panel-default no-box-shadow">
                <div class="panel-heading" style="padding: 30px 30px 10px 30px;">
                    <a><b class="h3"><?=$data['title'];?></b> - <?=$data['indexPage_message']?></a>
                </div>
                <div class="panel-body">
                    <div class="error" style="display: none; color: #f55753; margin-bottom: 10px;"></div>
                    <?=
                        Form::open(array(
                            'action' => Url::basePath('login'),
                            'method' => 'post',
                            'class' => 'login-form',
                            'csrf' => $data['csrf_token'],
                            'data-parsley-validate' => true
                        ));
                    ?>
                        <span hidden="hidden" class="csrf_token"><?=$data['csrf_token']?></span>
                        <input type="text" hidden="hidden" name="cloudName" id="cloudName" placeholder="Enter your cloud name" value="<?=$cloudName?>" required>
                        <div align="center">
                            <img class="profileImg" src="<?=Url::profilePic($data['userName'])?>" alt="PARABLU" title="web">
                        </div>
                        <div align="center">
                            <h4><?=$data['userName']?></h4>
                        </div>
                        <div class="form-group hide">
                            <label for="username"><?=Language::show('username', 'keywords');?></label>
                            <input type="text" class="form-control" name="username" id="username" placeholder="<?=Language::show('enter_your', 'keywords');?> <?=Language::show('username', 'keywords');?>" required readonly value="<?=$data['userName'];?>">
                        </div>
                        <div class="form-group">
                            <label for="password"><?=Language::show('password', 'keywords');?></label>
                            <input type="password" class="form-control" name="password" id="password" placeholder="<?=Language::show('enter_your', 'keywords');?> <?=Language::show('password', 'keywords');?>" required autocomplete="new-password" autofocus>
                        </div>
                        <?php if(multifactorAuthWithAccessCode == true){ ?>
                        <div class="form-group accessKeyDiv">
                            <label for="accessKey">Enter One Time Access Code sent to the registered Email address - <a  id="generateOtpLink" style="cursor:pointer;">Resend One Time Access Code</a></label>
                            <input type="text" class="form-control" name="accessKey" id="accessKey" placeholder="<?=Language::show('Enter', 'keywords');?> <?=Language::show('One Time Access Code', 'keywords');?>" required autocomplete="off">
                        </div>
                        <?php } ?>
                        <?php if(enableRecaptcha == true){ ?>
                        <div class="row hide">
                            <div class="col-lg-6">
                                <!--<div class="g-recaptcha" data-sitekey="<?php echo RECAPTCHA_SITE_KEY;?>"></div>-->
                                <div class="g-recaptcha" data-sitekey="6LdjbN0UAAAAAJJHP5ZaYSd4hBZSbwQ5eQ8xVcio"></div>
                            </div>
                        </div>
                        <?php } ?>
                        <?php if(googleAuthenticator == true){ ?>
                            <div class="form-group hide">
                                <label>Enter Google Authenticator Code -
                                <a data-toggle="collapse" href="#qrCollapse" role="button" aria-expanded="false" aria-controls="qrCollapse"><span class="aa">Show QR Code</span><span class="aa hide">Hide QR Code</span></a>
                                </label>
                                <input class="form-control" type="text" name="code" />
                            </div>
                            <div class="collapse hide" id="qrCollapse">
                                <center><div id="img">
                                <img src='<?php echo $qrCodeUrl; ?>' />
                                </div></center>
                            </div>
                        <?php } ?>
                        <a class="btn btn-danger pull-right" style="margin-left: 20px;" href="<?=Url::basePath('logout')?>"><?=Language::show('logout', 'keywords');?></a>
                        <button type="submit" class="login btn btn-success pull-right"><?=Language::show('unlock', 'keywords');?></button>
                    <?=
                        Form::close();
                    ?>
                </div>
            </div>
        </div>
    </div>
</div>
